@@ -1,6 +1,9 @@
 package Tcl::pTk::Submethods;
 
-our ($VERSION) = ('1.04');
+our ($VERSION) = ('1.05');
+
+use warnings;
+use strict;
 
 sub import
 {
